@@ -1,7 +1,7 @@
 package App::CSelUtils;
 
-our $DATE = '2016-09-01'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2019-07-26'; # DATE
+our $VERSION = '0.080'; # VERSION
 
 use 5.010001;
 use strict;
@@ -210,6 +210,21 @@ sub do_actions_on_nodes {
 $SPEC{ddsel} = {
     v => 1.1,
     summary => 'Select Perl data structure elements using CSel (CSS-selector-like) syntax',
+    description => <<'_',
+
+Note that this operates against Perl data structure, not Perl source code
+elements (see <prog:ppisel> for that). File is Perl source code that defines
+data structure, e.g.:
+
+    {
+        summary => 'This is a hash',
+        # this is an array inside a hash
+        array => [
+            1, 2, 3,
+        ],
+    };
+
+_
     args => {
         %foosel_common_args,
         %foosel_struct_action_args,
@@ -228,7 +243,7 @@ sub ddsel {
 
     my $data;
     if ($args{file} eq '-') {
-        binmode STDIN, ":utf8";
+        binmode STDIN, ":encoding(utf8)";
         $data = eval join("", <>);
         die if $@;
     } else {
@@ -251,7 +266,7 @@ sub ddsel {
 
     for my $action (@$actions) {
         if ($action eq 'print') {
-            $action = 'print_func_or_meth:meth:value.func:Data::Dmp::dmp',
+            $action = 'print_func_or_meth:meth:value.func:Data::Dmp::dmp';
         }
     }
 
@@ -278,7 +293,7 @@ App::CSelUtils - Utilities related to Data::CSel
 
 =head1 VERSION
 
-This document describes version 0.07 of App::CSelUtils (from Perl distribution App-CSelUtils), released on 2016-09-01.
+This document describes version 0.080 of App::CSelUtils (from Perl distribution App-CSelUtils), released on 2019-07-26.
 
 =head1 DESCRIPTION
 
@@ -295,10 +310,26 @@ This distribution contains the following utilities:
 =head1 FUNCTIONS
 
 
-=head2 ddsel(%args) -> [status, msg, result, meta]
+=head2 ddsel
+
+Usage:
+
+ ddsel(%args) -> [status, msg, payload, meta]
 
 Select Perl data structure elements using CSel (CSS-selector-like) syntax.
 
+Note that this operates against Perl data structure, not Perl source code
+elements (see L<ppisel> for that). File is Perl source code that defines
+data structure, e.g.:
+
+ {
+     summary => 'This is a hash',
+     # this is an array inside a hash
+     array => [
+         1, 2, 3,
+     ],
+ };
+
 This function is not exported.
 
 Arguments ('*' denotes required arguments):
@@ -320,14 +351,19 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
-=head2 parse_csel(%args) -> [status, msg, result, meta]
+
+=head2 parse_csel
+
+Usage:
+
+ parse_csel(%args) -> [status, msg, payload, meta]
 
 Parse CSel expression.
 
@@ -346,7 +382,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -372,7 +408,7 @@ feature.
 
 =head1 SEE ALSO
 
-L<htmlsel>, L<orgsel>, L<jsonsel>, L<yamlsel>
+L<htmlsel>, L<orgsel>, L<jsonsel>, L<yamlsel>, L<podsel>, L<ppisel>
 
 =head1 AUTHOR
 
@@ -380,7 +416,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
